# eolearn.mask subpackage

The deprecated way to install `eolearn.mask`. See [migration guide](https://github.com/sentinel-hub/eo-learn/issues/733) on how to correctly install the `eo-learn` package.

Installs requirements and a dummy package that is detected by `eo-learn` but otherwise does not change anything.
